d1W <-
function(z) {
if (abs(z[1])== 0) out=1
else out=(exp(W(z))+z)^(-1)
return(out)
}

